@@ -88,7 +88,7 @@ static void SDLSetWindowIcon(char *basename)
   SDL_SetColorKey(surface, SDL_SRCCOLORKEY,
 		  SDL_MapRGB(surface->format, 0x00, 0x00, 0x00));
 
- // SDL_WM_SetIcon(surface, NULL);
+  SDL_WM_SetIcon(surface, NULL);
 #endif
 }
 
@@ -113,8 +113,8 @@ void SDLInitVideoBuffer(DrawBuffer **backbuffer, DrawWindow **window,
   static int screen_xy[][2] =
   {
     {  640, 480 },
-    {  800, 480 },
-    {  800, 480 },
+    {  800, 600 },
+    { 1024, 768 },
     {   -1,  -1 }
   };
   SDL_Rect **modes;
@@ -143,8 +143,8 @@ void SDLInitVideoBuffer(DrawBuffer **backbuffer, DrawWindow **window,
 #if 1
   checked_free(video.fullscreen_modes);
 
-//  video.fullscreen_modes = NULL;
-//  video.fullscreen_mode_current = NULL;
+  video.fullscreen_modes = NULL;
+  video.fullscreen_mode_current = NULL;
 #endif
 
   /* get available hardware supported fullscreen modes */
@@ -153,9 +153,7 @@ void SDLInitVideoBuffer(DrawBuffer **backbuffer, DrawWindow **window,
   if (modes == NULL)
   {
     /* no screen modes available => no fullscreen mode support */
-    video.fullscreen_available = TRUE;
-    video.fullscreen_modes[0].width  = 800;
-    video.fullscreen_modes[0].height = 480;;
+    video.fullscreen_available = FALSE;
   }
   else if (modes == (SDL_Rect **)-1)
   {
@@ -163,11 +161,11 @@ void SDLInitVideoBuffer(DrawBuffer **backbuffer, DrawWindow **window,
     video.fullscreen_modes = checked_calloc(2 * sizeof(struct ScreenModeInfo));
 
     /* use native video buffer size for fullscreen mode */
-    video.fullscreen_modes[0].width  = 800;
-    video.fullscreen_modes[0].height = 480;
+    video.fullscreen_modes[0].width  = video.width;
+    video.fullscreen_modes[0].height = video.height;
 
-    //video.fullscreen_modes[1].width  = -1;
-    //video.fullscreen_modes[1].height = -1;
+    video.fullscreen_modes[1].width  = -1;
+    video.fullscreen_modes[1].height = -1;
   }
   else
   {
@@ -209,7 +207,7 @@ void SDLInitVideoBuffer(DrawBuffer **backbuffer, DrawWindow **window,
     if (num_modes == 0)
     {
       /* no appropriate screen modes available => no fullscreen mode support */
-      video.fullscreen_available = TRUE;
+      video.fullscreen_available = FALSE;
     }
   }
 
@@ -274,7 +272,7 @@ boolean SDLSetVideoMode(DrawBuffer **backbuffer, boolean fullscreen)
       Error(ERR_WARN, "SDL_SetVideoMode() failed: %s", SDL_GetError());
 
       /* do not try it again */
-      video.fullscreen_available = TRUE;
+      video.fullscreen_available = FALSE;
 
       success = FALSE;
     }
@@ -308,7 +306,7 @@ boolean SDLSetVideoMode(DrawBuffer **backbuffer, boolean fullscreen)
     {
       (*backbuffer)->surface = new_surface;
 
-      video.fullscreen_enabled = TRUE;
+      video.fullscreen_enabled = FALSE;
 
       success = TRUE;
     }
@@ -1336,12 +1334,17 @@ int zoomSurfaceRGBA_scaleDownBy2(SDL_Surface *src, SDL_Surface *dst)
 {
   int x, y;
   tColorRGBA *sp, *csp, *dp;
-  int sgap, dgap;
+#if 0
+  int sgap;
+#endif
+  int dgap;
 
   /* pointer setup */
   sp = csp = (tColorRGBA *) src->pixels;
   dp = (tColorRGBA *) dst->pixels;
+#if 0
   sgap = src->pitch - src->w * 4;
+#endif
   dgap = dst->pitch - dst->w * 4;
 
   for (y = 0; y < dst->h; y++)
@@ -1388,7 +1391,10 @@ int zoomSurfaceRGBA(SDL_Surface *src, SDL_Surface *dst)
 {
   int x, y, sx, sy, *sax, *say, *csax, *csay, csx, csy;
   tColorRGBA *sp, *csp, *dp;
-  int sgap, dgap;
+#if 0
+  int sgap;
+#endif
+  int dgap;
 
   /* use specialized zoom function when scaling down to exactly half size */
   if (src->w == 2 * dst->w &&
@@ -1427,7 +1433,9 @@ int zoomSurfaceRGBA(SDL_Surface *src, SDL_Surface *dst)
   /* pointer setup */
   sp = csp = (tColorRGBA *) src->pixels;
   dp = (tColorRGBA *) dst->pixels;
+#if 0
   sgap = src->pitch - src->w * 4;
+#endif
   dgap = dst->pitch - dst->w * 4;
 
   csay = say;
